@@ -1,4 +1,5 @@
 make_node_measure <- function(out, .data) {
+  if(manynet::is_labelled(.data)) names(out) <- manynet::node_names(.data)
   class(out) <- c("node_measure", class(out))
   attr(out, "mode") <- manynet::node_mode(.data)
   out
@@ -28,26 +29,29 @@ make_network_measures <- function(out, .data) {
 # Printing ####
 #' @export
 print.node_measure <- function(x, ...,
-                          max.length = 6,
-                          digits = 3) {
+                          n = NULL, digits = 3){
   if (any(attr(x, "mode"))) {
     for(m in c(FALSE, TRUE)){
-      print_tblvec(y = as.numeric(x)[attr(x, "mode")==m], 
-                   names = list(names(x)[attr(x, "mode")==m]))
+      print_tblvec(y = round(as.numeric(x)[attr(x, "mode") == m], 
+                             digits = digits), 
+                   names = list(names(x)[attr(x, "mode") == m]),
+                   n = n)
       if(!m) cat("\n")
     }
   } else {
-    print_tblvec(y = as.numeric(x), 
-                 names = list(names(x)))
+    print_tblvec(y = round(as.numeric(x), 
+                           digits = digits), 
+                 names = list(names(x)),
+                 n = n)
   }
 }
 
 #' @export
 print.tie_measure <- function(x, ...,
-                               max.length = 6,
+                               n = NULL,
                                digits = 3) {
-  print_tblvec(y = as.numeric(x), 
-               names = list(names(x)))
+  print_tblvec(y = round(as.numeric(x), digits = digits), 
+               names = list(names(x)), n = n)
 }
 
 #' @export
@@ -66,7 +70,7 @@ print.network_measure <- function(x, ...,
 # @param FUN A function by which the values should be aggregated
 # or summarised. By default `mean`.
 # summary(node_degree(mpn_elite_mex),
-#         membership = node_structural_equivalence(mpn_elite_mex, select = "elbow"))
+#         membership = node_structural_equivalence(mpn_elite_mex, k = "elbow"))
 #' @export
 summary.node_measure <- function(object, ...,
                                  membership,
@@ -80,47 +84,34 @@ summary.node_measure <- function(object, ...,
 # Plotting ####
 #' @export
 plot.node_measure <- function(x, type = c("h", "d"), ...) {
-  type <- match.arg(type)
-  if (is.null(attr(x, "mode")))
-    attr(x, "mode") <- rep(FALSE, length(x))
+  #type <- match.arg(type)
+  density <- NULL
+  if (is.null(attr(x, "mode"))) attr(x, "mode") <- rep(FALSE, length(x))
   data <- data.frame(Score = x, Mode = attr(x, "mode"))
-  if (any(attr(x, "mode"))) {
-    if (type == "h") {
-      p <- ggplot2::ggplot(data = data) +
-        ggplot2::geom_histogram(ggplot2::aes(x = .data$Score,
-                                             fill = .data$Mode),
-                                binwidth = ifelse(max(data$Score) > 1, 1,
-                                                  ifelse(max(data$Score) > .1,
-                                                         .1,
-                                                         .01))) +
-        ggplot2::ylab("Frequency") +
-        ggplot2::scale_fill_grey(labels = c("1", "2"),
-                                 start = 0.7, end = 0.4)
-    } else {
-      p <- ggplot2::ggplot(data = data) +
-        ggplot2::geom_density(ggplot2::aes(x = .data$Score,
-                                           color = .data$Mode)) +
-        ggplot2::ylab("Density") +
-        ggplot2::scale_color_grey(labels = c("1", "2"),
-                                  start = 0.7, end = 0.4)
-    }
-  } else {
-    # if (type == "h") {
-      p <- ggplot2::ggplot(data = data) +
-        ggplot2::geom_histogram(ggplot2::aes(x = .data$Score),
-                                binwidth = ifelse(max(data$Score) > 1, 1,
-                                                  ifelse(max(data$Score) > .1,
-                                                         .1,
-                                                         .01))) +
-    #     ggplot2::ylab("Frequency")
-    # } else {
-    #   p <- ggplot2::ggplot(data = data) +
-        ggplot2::geom_density(ggplot2::aes(x = .data$Score), col = 2) +
-        ggplot2::scale_y_continuous("Frequency", 
-                                    sec.axis = ggplot2::sec_axis(~ ., breaks = c(0,1), name = "Density"))
-    # }
+  if (length(type) == 2) {
+    p <- ggplot2::ggplot(data = data, ggplot2::aes(x = .data$Score)) +
+      ggplot2::geom_histogram(ggplot2::aes(y = ggplot2::after_stat(density)),
+                              binwidth = ifelse(max(data$Score) > 1, 1,
+                                                ifelse(max(data$Score) > 
+                                                         .1, .1, .01))) +
+      ggplot2::geom_density(col = 2) +
+      ggplot2::scale_y_continuous("Frequency", sec.axis = 
+                                    ggplot2::sec_axis(~ ., breaks = c(0,1),
+                                                      name = "Density"))
+  } else if (length(type) == 1 & type == "h") {
+    p <- ggplot2::ggplot(data = data, ggplot2::aes(x = .data$Score)) +
+      ggplot2::geom_histogram(ggplot2::aes(y = ggplot2::after_stat(density)),
+                              binwidth = ifelse(max(data$Score) > 1, 1,
+                                                ifelse(max(data$Score) >
+                                                         .1, .1, .01))) +
+      ggplot2::labs(x = "Density", y = "Frequency")
+  } else if (length(type) == 1 & type == "d") {
+    p <- ggplot2::ggplot(data = data, ggplot2::aes(x = .data$Score)) +
+      ggplot2::geom_density(col = 2) +
+      ggplot2::ylab("Density")
   }
-  p + ggplot2::theme_classic() +
+  p +
+    ggplot2::theme_classic() +
     ggplot2::theme(panel.grid.major = ggplot2::element_line(colour = "grey90"))
 }
 
@@ -156,17 +147,18 @@ plot.network_measures <- function(x, ...) {
   
 
 # make tblvec ####
-print_tblvec <- function(y, names){
+print_tblvec <- function(y, names, n){
   mat <- matrix(y, dimnames = names)
   mat <- t(mat)
   out <- as.data.frame(mat)
   tibs <- dplyr::tibble(out, .name_repair = "unique")
-  setup <- pillar::tbl_format_setup(tibs)
-  body <- pillar::tbl_format_body(tibs, setup)[c(1,3)]
+  setup <- pillar::tbl_format_setup(tibs, width = n)
+  body <- pillar::tbl_format_body(tibs, setup)[c(TRUE, FALSE, TRUE)]
   if(setup$extra_cols_total > 0){
         print(body)
     cat(pillar::style_subtle(paste("# ... with",
                                    setup$extra_cols_total,
-                                   "more from this nodeset in the vector.")))
+                                   "more values from this nodeset unprinted.",
+                                   "Use `print(..., n = Inf)` to print all values.")))
       } else print(body)
 }
